@@ -8,5 +8,5 @@ ROOT_URLCONF = ['fourstore.urls']
 TEMPLATE_DIRS = os.path.join(os.path.dirname(__file__), 'tests', 'templates')
 
 FOURSTORE_KBNAME = "django_4store"
-FOURSTORE_PORT = 6667
-SPARQL_ENDPOINT = "http://localhost:6667"
+FOURSTORE_PORT = 8666
+SPARQL_ENDPOINT = "http://localhost:%d" % FOURSTORE_PORT
